@@ -1,4 +1,4 @@
-/*	$NetBSD:$	*/
+/*	$NetBSD$	*/
 /*	$OpenBSD: ldc.c,v 1.12 2015/03/21 18:02:58 kettenis Exp $	*/
 /*
  * Copyright (c) 2009 Mark Kettenis
@@ -25,6 +25,7 @@
 
 #include <sparc64/dev/ldcvar.h>
 
+#define LDC_DEBUG
 #ifdef LDC_DEBUG
 #define DPRINTF(x)	printf x
 #else
@@ -496,9 +497,10 @@ ldc_reset(struct ldc_conn *lc)
 struct ldc_queue *
 ldc_queue_alloc(bus_dma_tag_t t, int nentries)
 {
+printf("%s\n", __FUNCTION__);
 	struct ldc_queue *lq;
 	bus_size_t size;
-	vaddr_t *va;
+	vaddr_t va = 0;
 	int nsegs;
 
 	lq = malloc(sizeof(struct ldc_queue), M_DEVBUF, M_NOWAIT);
@@ -521,16 +523,16 @@ ldc_queue_alloc(bus_dma_tag_t t, int nentries)
 	    BUS_DMA_NOWAIT) != 0)
 		goto free;
 
-	if (bus_dmamap_load(t, lq->lq_map, va, size, NULL,
+	 if (bus_dmamap_load(t, lq->lq_map, (void*)va, size, NULL,
 	    BUS_DMA_NOWAIT) != 0)
 		goto unmap;
 
-	lq->lq_va = *va;
+	lq->lq_va = (vaddr_t)va;
 	lq->lq_nentries = nentries;
 	return (lq);
 
 unmap:
-	bus_dmamem_unmap(t, va, size);
+ bus_dmamem_unmap(t, (void*)va, size);
 free:
 	bus_dmamem_free(t, &lq->lq_seg, 1);
 destroy:
@@ -556,9 +558,10 @@ ldc_queue_free(bus_dma_tag_t t, struct ldc_queue *lq)
 struct ldc_map *
 ldc_map_alloc(bus_dma_tag_t t, int nentries)
 {
+printf("%s\n", __FUNCTION__);
 	struct ldc_map *lm;
 	bus_size_t size;
-	vaddr_t *va;
+	vaddr_t va = 0;
 	int nsegs;
 
 	lm = malloc(sizeof(struct ldc_map), M_DEVBUF, M_NOWAIT);
@@ -566,30 +569,39 @@ ldc_map_alloc(bus_dma_tag_t t, int nentries)
 		return NULL;
 
 	size = roundup(nentries * sizeof(struct ldc_map_slot), PAGE_SIZE);
-
 	if (bus_dmamap_create(t, size, 1, size, 0,
-	    BUS_DMA_NOWAIT | BUS_DMA_ALLOCNOW, &lm->lm_map) != 0)
+			      BUS_DMA_NOWAIT | BUS_DMA_ALLOCNOW, &lm->lm_map) != 0) {
+		DPRINTF(("ldc_map_alloc() - bus_dmamap_create() failed\n"));
 		return (NULL);
+	}
 
 	if (bus_dmamem_alloc(t, size, PAGE_SIZE, 0, &lm->lm_seg, 1,
-	    &nsegs, BUS_DMA_NOWAIT) != 0)
+			     &nsegs, BUS_DMA_NOWAIT) != 0) {
+		DPRINTF(("ldc_map_alloc() - bus_dmamem_alloc() failed\n"));
 		goto destroy;
+	}
 
-	if (bus_dmamem_map(t, &lm->lm_seg, 1, size, (void **)&va,
-	    BUS_DMA_NOWAIT) != 0)
+	if (bus_dmamem_map(t, &lm->lm_seg, 1, size, (void *)&va,
+			   BUS_DMA_NOWAIT) != 0) {
+		DPRINTF(("ldc_map_alloc() - bus_dmamem_map() failed\n"));
 		goto free;
-
-	if (bus_dmamap_load(t, lm->lm_map, va, size, NULL,
-	    BUS_DMA_NOWAIT) != 0)
+	}
+	if (bus_dmamap_load(t, lm->lm_map, (void*)va, size, NULL,
+			    BUS_DMA_NOWAIT) != 0) {
+		DPRINTF(("ldc_map_alloc() - bus_dmamap_load() failed\n"));
 		goto unmap;
+	}
 
-	lm->lm_slot = (struct ldc_map_slot *)*va;
+	lm->lm_slot = (struct ldc_map_slot *)va;
 	lm->lm_nentries = nentries;
+#if 0
+FIXME enable again when pa stuff works
 	bzero(lm->lm_slot, nentries * sizeof(struct ldc_map_slot));
+#endif
 	return (lm);
 
 unmap:
-	bus_dmamem_unmap(t, va, size);
+	bus_dmamem_unmap(t, (void*)va, size);
 free:
 	bus_dmamem_free(t, &lm->lm_seg, 1);
 destroy:
