@@ -1,4 +1,4 @@
-/*	$NetBSD:$	*/
+/*	$NetBSD$	*/
 /*	$OpenBSD: vdsk.c,v 1.46 2015/01/25 21:42:13 kettenis Exp $	*/
 /*
  * Copyright (c) 2009, 2011 Mark Kettenis
@@ -238,9 +238,12 @@ vdsk_match(device_t parent, cfdata_t match, void *aux)
 void
 vdsk_attach(device_t parent, device_t self, void *aux)
 {
-	struct vdsk_softc *sc = (struct vdsk_softc *)self;
+	struct vdsk_softc *sc = device_private(self);
 	struct cbus_attach_args *ca = aux;
+#if 0 
+FIXME openbsd
 	struct scsibus_attach_args saa;
+#endif
 	struct ldc_conn *lc;
 	int err, s;
 	int timeout;
@@ -248,7 +251,9 @@ vdsk_attach(device_t parent, device_t self, void *aux)
 	sc->sc_bustag = ca->ca_bustag;
 	sc->sc_dmatag = ca->ca_dmatag;
 
-	printf(": ivec 0x%llx, 0x%llx", ca->ca_tx_ino, ca->ca_rx_ino);
+	printf(": ivec 0x%llx, 0x%llx", 
+	       (long long unsigned int)ca->ca_tx_ino,
+	       (long long unsigned int)ca->ca_rx_ino);
 
 	/*
 	 * Un-configure queues before registering interrupt handlers,
@@ -256,7 +261,8 @@ vdsk_attach(device_t parent, device_t self, void *aux)
 	 */
 	hv_ldc_tx_qconf(ca->ca_id, 0, 0);
 	hv_ldc_rx_qconf(ca->ca_id, 0, 0);
-
+#if 0
+FIXME openbsd
 	sc->sc_tx_ih = bus_intr_establish(ca->ca_bustag, ca->ca_tx_ino,
 	    IPL_BIO, 0, vdsk_tx_intr, sc, sc->sc_dv.dv_xname);
 	sc->sc_rx_ih = bus_intr_establish(ca->ca_bustag, ca->ca_rx_ino,
@@ -265,7 +271,7 @@ vdsk_attach(device_t parent, device_t self, void *aux)
 		printf(", can't establish interrupt\n");
 		return;
 	}
-
+#endif
 	lc = &sc->sc_lc;
 	lc->lc_id = ca->ca_id;
 	lc->lc_sc = sc;
@@ -278,36 +284,45 @@ vdsk_attach(device_t parent, device_t self, void *aux)
 		printf(", can't allocate tx queue\n");
 		return;
 	}
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	lc->lc_rxq = ldc_queue_alloc(sc->sc_dmatag, VDSK_RX_ENTRIES);
 	if (lc->lc_rxq == NULL) {
 		printf(", can't allocate rx queue\n");
 		goto free_txqueue;
 	}
+printf("%s:%d\n", __FILE__, __LINE__);
 
-	sc->sc_lm = ldc_map_alloc(sc->sc_dmatag, 2048);
+/* FIXME 2048 -> 16 */
+	sc->sc_lm = ldc_map_alloc(sc->sc_dmatag, 16);
 	if (sc->sc_lm == NULL) {
 		printf(", can't allocate LDC mapping table\n");
 		goto free_rxqueue;
 	}
-
+printf("%s:%d\n", __FILE__, __LINE__);
 	err = hv_ldc_set_map_table(lc->lc_id,
 	    sc->sc_lm->lm_map->dm_segs[0].ds_addr, sc->sc_lm->lm_nentries);
 	if (err != H_EOK) {
 		printf("hv_ldc_set_map_table %d\n", err);
+#if 0
+FIXME enable again when pa stuff works
 		goto free_map;
+#endif
 	}
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	sc->sc_vd = vdsk_dring_alloc(sc->sc_dmatag, 32);
 	if (sc->sc_vd == NULL) {
 		printf(", can't allocate dring\n");
 		goto free_map;
 	}
+printf("%s:%d\n", __FILE__, __LINE__);
 	sc->sc_vsd = malloc(32 * sizeof(*sc->sc_vsd), M_DEVBUF, M_NOWAIT);
 	if (sc->sc_vsd == NULL) {
 		printf(", can't allocate software ring\n");
 		goto free_dring;
 	}
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	sc->sc_lm->lm_slot[0].entry = sc->sc_vd->vd_map->dm_segs[0].ds_addr;
 	sc->sc_lm->lm_slot[0].entry &= LDC_MTE_RA_MASK;
@@ -315,21 +330,27 @@ vdsk_attach(device_t parent, device_t self, void *aux)
 	sc->sc_lm->lm_slot[0].entry |= LDC_MTE_R | LDC_MTE_W;
 	sc->sc_lm->lm_next = 1;
 	sc->sc_lm->lm_count = 1;
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	err = hv_ldc_tx_qconf(lc->lc_id,
 	    lc->lc_txq->lq_map->dm_segs[0].ds_addr, lc->lc_txq->lq_nentries);
 	if (err != H_EOK)
 		printf("hv_ldc_tx_qconf %d\n", err);
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	err = hv_ldc_rx_qconf(lc->lc_id,
 	    lc->lc_rxq->lq_map->dm_segs[0].ds_addr, lc->lc_rxq->lq_nentries);
 	if (err != H_EOK)
 		printf("hv_ldc_rx_qconf %d\n", err);
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	cbus_intr_setenabled(sc->sc_bustag, ca->ca_tx_ino, INTR_ENABLED);
+printf("%s:%d\n", __FILE__, __LINE__);
 	cbus_intr_setenabled(sc->sc_bustag, ca->ca_rx_ino, INTR_ENABLED);
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	ldc_send_vers(lc);
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	printf("\n");
 
@@ -340,12 +361,14 @@ vdsk_attach(device_t parent, device_t self, void *aux)
 	s = splbio();
 	timeout = 1000;
 	do {
+printf("%s:%d\n", __FILE__, __LINE__);
 		if (vdsk_rx_intr(sc) && sc->sc_vio_state == VIO_ESTABLISHED)
 			break;
 
 		delay(1000);
 	} while(--timeout > 0);
 	splx(s);
+printf("%s:%d\n", __FILE__, __LINE__);
 
 	if (sc->sc_vio_state != VIO_ESTABLISHED)
 		return;
@@ -376,10 +399,12 @@ FIXME openbsd
 	sc->sc_link.pool = &sc->sc_iopool;
 #endif
 
+#if 0
+FIXME openbsd
 	bzero(&saa, sizeof(saa));
 	saa.saa_sc_link = &sc->sc_link;
 	config_found(self, &saa, scsiprint);
-
+#endif
 	return;
 
 free_dring:
@@ -673,8 +698,10 @@ vdsk_rx_vio_rdx(struct vdsk_softc *sc, struct vio_msg_tag *tag)
 		sc->sc_lm->lm_count = 1;
 		while (sc->sc_tx_prod != prod)
 			vdsk_submit_cmd(sc->sc_vsd[sc->sc_tx_prod].vsd_xs);
-
+#if 0
+FIXME openbsd
 		scsi_iopool_run(&sc->sc_iopool);
+#endif
 		break;
 	}
 
@@ -716,6 +743,8 @@ vdsk_rx_vio_dring_data(struct vdsk_softc *sc, struct vio_msg_tag *tag)
 
 	case VIO_SUBTYPE_ACK:
 	{
+#if 0
+FIXME openbsd
 		struct scsi_xfer *xs;
 		int cons;
 
@@ -728,6 +757,7 @@ vdsk_rx_vio_dring_data(struct vdsk_softc *sc, struct vio_msg_tag *tag)
 			cons &= (sc->sc_vd->vd_nentries - 1);
 		}
 		sc->sc_tx_cons = cons;
+#endif
 		break;
 	}
 
@@ -774,7 +804,7 @@ vdsk_send_ver_info(struct vdsk_softc *sc, uint16_t major, uint16_t minor)
 	struct vio_ver_info vi;
 
 	/* Allocate new session ID. */
-	sc->sc_local_sid = tick();
+	sc->sc_local_sid = gettick();
 
 	bzero(&vi, sizeof(vi));
 	vi.tag.type = VIO_TYPE_CTRL;
@@ -849,9 +879,12 @@ vdsk_dring_alloc(bus_dma_tag_t t, int nentries)
 {
 	struct vdsk_dring *vd;
 	bus_size_t size;
-	caddr_t va;
+	vaddr_t va;
 	int nsegs;
+#if 0
+FIXME enable again when pa stuff works
 	int i;
+#endif
 
 	vd = malloc(sizeof(struct vdsk_dring), M_DEVBUF, M_NOWAIT);
 	if (vd == NULL)
@@ -867,23 +900,26 @@ vdsk_dring_alloc(bus_dma_tag_t t, int nentries)
 	    &nsegs, BUS_DMA_NOWAIT) != 0)
 		goto destroy;
 
-	if (bus_dmamem_map(t, &vd->vd_seg, 1, size, &va,
+	if (bus_dmamem_map(t, &vd->vd_seg, 1, size, (void*)&va,
 	    BUS_DMA_NOWAIT) != 0)
 		goto free;
 
-	if (bus_dmamap_load(t, vd->vd_map, va, size, NULL,
+	if (bus_dmamap_load(t, vd->vd_map, (void*)va, size, NULL,
 	    BUS_DMA_NOWAIT) != 0)
 		goto unmap;
 
 	vd->vd_desc = (struct vd_desc *)va;
 	vd->vd_nentries = nentries;
+#if 0
+FIXME enable again when pa stuff works
 	bzero(vd->vd_desc, nentries * sizeof(struct vd_desc));
 	for (i = 0; i < vd->vd_nentries; i++)
 		vd->vd_desc[i].hdr.dstate = VIO_DESC_FREE;
+#endif
 	return (vd);
 
 unmap:
-	bus_dmamem_unmap(t, va, size);
+	bus_dmamem_unmap(t, (void*)va, size);
 free:
 	bus_dmamem_free(t, &vd->vd_seg, 1);
 destroy:
@@ -901,10 +937,13 @@ vdsk_dring_free(bus_dma_tag_t t, struct vdsk_dring *vd)
 	size = roundup(size, PAGE_SIZE);
 
 	bus_dmamap_unload(t, vd->vd_map);
+#if 0
+FIXME openbsd
 	bus_dmamem_unmap(t, (caddr_t)vd->vd_desc, size);
+#endif
 	bus_dmamem_free(t, &vd->vd_seg, 1);
 	bus_dmamap_destroy(t, vd->vd_map);
-	free(vd, M_DEVBUF, 0);
+	free(vd, M_DEVBUF);
 }
 
 void *
@@ -944,6 +983,8 @@ vdsk_io_put(void *xsc, void *io)
 void
 vdsk_scsi_cmd(struct scsi_xfer *xs)
 {
+#if 0
+FIXME openbsd
 	struct vdsk_softc *sc = xs->sc_link->adapter_softc;
 	int timeout, s;
 	int desc;
@@ -1008,11 +1049,14 @@ vdsk_scsi_cmd(struct scsi_xfer *xs)
 		vdsk_scsi_done(xs, XS_TIMEOUT);
 	}
 	splx(s);
+#endif
 }
 
 int
 vdsk_submit_cmd(struct scsi_xfer *xs)
 {
+#if 0
+FIXME openbsd
 	struct vdsk_softc *sc = xs->sc_link->adapter_softc;
 	struct ldc_map *map = sc->sc_lm;
 	struct vio_dring_msg dm;
@@ -1131,11 +1175,16 @@ vdsk_submit_cmd(struct scsi_xfer *xs)
 	vdsk_sendmsg(sc, &dm, sizeof(dm));
 
 	return desc;
+#else
+	return -1;
+#endif
 }
 
 void
 vdsk_complete_cmd(struct scsi_xfer *xs, int desc)
 {
+#if 0
+FIXME openbsd
 	struct vdsk_softc *sc = xs->sc_link->adapter_softc;
 	struct ldc_map *map = sc->sc_lm;
 	int cookie, idx;
@@ -1156,22 +1205,28 @@ vdsk_complete_cmd(struct scsi_xfer *xs, int desc)
 	vdsk_scsi_done(xs, error);
 
 	sc->sc_vd->vd_desc[desc].hdr.dstate = VIO_DESC_FREE;
+#endif
 }
 
 void
 vdsk_scsi_inq(struct scsi_xfer *xs)
 {
+#if 0
+FIXME openbsd
 	struct scsi_inquiry *inq = (struct scsi_inquiry *)xs->cmd;
 
 	if (ISSET(inq->flags, SI_EVPD))
 		vdsk_scsi_done(xs, XS_DRIVER_STUFFUP);
 	else
 		vdsk_scsi_inquiry(xs);
+#endif
 }
 
 void
 vdsk_scsi_inquiry(struct scsi_xfer *xs)
 {
+#if 0
+FIXME openbsd
 	struct vdsk_softc *sc = xs->sc_link->adapter_softc;
 	struct scsi_inquiry_data inq;
 	char buf[5];
@@ -1202,11 +1257,14 @@ vdsk_scsi_inquiry(struct scsi_xfer *xs)
 	bcopy(&inq, xs->data, MIN(sizeof(inq), xs->datalen));
 
 	vdsk_scsi_done(xs, XS_NOERROR);
+#endif
 }
 
 void
 vdsk_scsi_capacity(struct scsi_xfer *xs)
 {
+#if 0
+FIXME openbsd
 	struct vdsk_softc *sc = xs->sc_link->adapter_softc;
 	struct scsi_read_cap_data rcd;
 	uint64_t capacity;
@@ -1223,11 +1281,14 @@ vdsk_scsi_capacity(struct scsi_xfer *xs)
 	bcopy(&rcd, xs->data, MIN(sizeof(rcd), xs->datalen));
 
 	vdsk_scsi_done(xs, XS_NOERROR);
+#endif
 }
 
 void
 vdsk_scsi_capacity16(struct scsi_xfer *xs)
 {
+#if 0
+FIXME openbsd
 	struct vdsk_softc *sc = xs->sc_link->adapter_softc;
 	struct scsi_read_cap_data_16 rcd;
 
@@ -1239,16 +1300,22 @@ vdsk_scsi_capacity16(struct scsi_xfer *xs)
 	bcopy(&rcd, xs->data, MIN(sizeof(rcd), xs->datalen));
 
 	vdsk_scsi_done(xs, XS_NOERROR);
+#endif
 }
 
 void
 vdsk_scsi_done(struct scsi_xfer *xs, int error)
 {
+#if 0
+FIXME openbsd
 	xs->error = error;
 
 	scsi_done(xs);
+#endif
 }
 
+#if 0
+FIXME openbsd
 int
 vdsk_dev_probe(struct scsi_link *link)
 {
@@ -1256,12 +1323,15 @@ vdsk_dev_probe(struct scsi_link *link)
 
 	if (link->target == 0)
 		return (0);
-
 	return (ENODEV);
 }
+#endif
 
+#if 0
+FIXME openbsd
 void
 vdsk_dev_free(struct scsi_link *link)
 {
 	printf("%s\n", __func__);
 }
+#endif
