@@ -16,7 +16,10 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#if 0
+FIXME openbsd
 #include "bpfilter.h"
+#endif
 
 #include <sys/param.h>
 #include <sys/atomic.h>
@@ -27,7 +30,10 @@
 #include <sys/socket.h>
 #include <sys/sockio.h>
 #include <sys/systm.h>
+#if 0
+FIXME openbsd
 #include <sys/timeout.h>
+#endif
 
 #include <machine/autoconf.h>
 #include <machine/hypervisor.h>
@@ -37,7 +43,10 @@
 #include <net/if_media.h>
 
 #include <netinet/in.h>
+#if 0
+FIXME openbsd
 #include <netinet/if_ether.h>
+#endif
 
 #if NBPFILTER > 0
 #include <net/bpf.h>
