@@ -1,4 +1,4 @@
-/*	$NetBSD: vpci.c,v 1.6 2015/11/27 13:51:57 joerg Exp $	*/
+/*	$NetBSD: vpci.c,v 1.7 2016/05/10 19:23:59 palle Exp $	*/
 /*
  * Copyright (c) 2015 Palle Lyckegaard
  * All rights reserved.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: vpci.c,v 1.6 2015/11/27 13:51:57 joerg Exp $");
+__KERNEL_RCSID(0, "$NetBSD: vpci.c,v 1.7 2016/05/10 19:23:59 palle Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
@@ -62,7 +62,7 @@ __KERNEL_RCSID(0, "$NetBSD: vpci.c,v 1.6 2015/11/27 13:51:57 joerg Exp $");
 #define VDB_CONF_READ        0x08
 #define VDB_CONF_WRITE       0x10
 #define VDB_CONF             VDB_CONF_READ|VDB_CONF_WRITE
-int vpci_debug = 0x00|VDB_INTR;
+int vpci_debug = 0x00;
 #define DPRINTF(l, s)   do { if (vpci_debug & l) printf s; } while (0)
 #else
 #define DPRINTF(l, s)
@@ -494,6 +494,7 @@ vpci_dmamap_create(bus_dma_tag_t t, bus_size_t size,
     int nsegments, bus_size_t maxsegsz, bus_size_t boundary, int flags,
     bus_dmamap_t *dmamp)
 {
+printf("%s\n", __FUNCTION__);
 	struct vpci_pbm *pbm = t->_cookie;
 	int error;
 
@@ -613,23 +614,20 @@ vpci_intr_establish(bus_space_tag_t t, int ihandle, int level,
 	int err;
 
 	err = hv_intr_settarget(sysino, cpus->ci_cpuid);
-	if (err != H_EOK) {
-	  panic("hv_intr_settarget(%lu, %u) failed - err = %d\n", 
-		(long unsigned int)sysino, cpus->ci_cpuid, err);
-	} 
+	if (err != H_EOK)
+		printf("hv_intr_settarget(%lu, %u) failed - err = %d\n", 
+		       (long unsigned int)sysino, cpus->ci_cpuid, err);
 
 	/* Clear pending interrupts. */
 	err = hv_intr_setstate(sysino, INTR_IDLE);
-	if (err != H_EOK) {
-	  panic("hv_intr_setstate(%lu, INTR_IDLE) failed - err = %d\n", 
+	if (err != H_EOK)
+	  printf("hv_intr_setstate(%lu, INTR_IDLE) failed - err = %d\n", 
 		(long unsigned int)sysino, err);
-	}
 
 	err = hv_intr_setenabled(sysino, INTR_ENABLED);
-	if (err != H_EOK) {
-	  panic("hv_intr_setenabled(%lu) failed - err = %d\n", 
+	if (err != H_EOK)
+	  printf("hv_intr_setenabled(%lu) failed - err = %d\n", 
 		(long unsigned int)sysino, err);
-	}
 
 	DPRINTF(VDB_INTR, ("%s() returning %p\n", __func__, ih));
 	return (ih);
@@ -639,12 +637,10 @@ void
 vpci_intr_ack(struct intrhand *ih)
 {
 	int err;
-  /* FIXME check that ih_number is sysino */  
-	printf("vpci_intr_ack() ih_number %u\n", ih->ih_number);
 	err = hv_intr_setstate(ih->ih_number, INTR_IDLE);
 	if (err != H_EOK)
-	  panic("hv_intr_setstate(%u, INTR_IDLE) failed - err = %d\n", 
-		ih->ih_number, err);
+	  panic("%s(%u, INTR_IDLE) failed - err = %d\n", 
+		__func__, ih->ih_number, err);
 }
 
 static void *
